These deprecated functions have been replaced by revised functions and will be removed in future releases of the energy package.
dcor.ttest(x, y, distance=FALSE)
dcor.t(x, y, distance=FALSE)data or distances of first sample
data or distances of second sample
logical: TRUE if x and y are distances
* dcor.t has been replaced by dcorT. See dcorT for details.
* dcor.ttest has been replaced by dcorT.test. See dcorT.test for details.